componenttools.get_component_in_expr_with_name
==============================================

.. autofunction:: abjad.tools.componenttools.get_component_in_expr_with_name.get_component_in_expr_with_name
